package me.teridax.jcash.gui.account;

import me.teridax.jcash.Logging;
import me.teridax.jcash.Main;
import me.teridax.jcash.banking.management.BankingManagementSystem;
import me.teridax.jcash.banking.management.Profile;
import me.teridax.jcash.gui.deposit.DepositDialog;
import me.teridax.jcash.gui.takeoff.TakeoffDialog;
import me.teridax.jcash.gui.transfer.TransferDialog;

/**
 * Controller for controlling the gui of an account.
 */
public class AccountController {
    private final AccountData data;
    /**
     * GUI if an account
     */
    private final AccountView view;

    private final Profile profile;

    public AccountController(Profile profile, BankingManagementSystem bms) {
        this.profile = profile;
        this.view = new AccountView();
        this.view.setProfile(profile);
        this.data = new AccountData(bms);

        createListeners(profile);
    }

    private void createListeners(Profile profile) {
        this.view.getAccountSelection().addActionListener(e -> changeAccount());

        this.view.getLogout().addActionListener(e -> logout());

        this.view.getDeposit().addActionListener(e -> new DepositDialog(profile.getPrimaryAccount(), () -> this.view.setProfile(profile)));

        this.view.getTakeoff().addActionListener(e -> new TakeoffDialog(profile.getPrimaryAccount(), () -> this.view.setProfile(profile)));

        this.view.getTransfer().addActionListener(e -> new TransferDialog(profile.getPrimaryAccount(), data.getBms(), () -> this.view.setProfile(profile)));
    }

    private void logout() {
        Logging.LOGGER.fine("Logging out of account");
        Main.getInstance().logout();
        Main.getInstance().showLoginScreen();
    }

    private void changeAccount() {
        var description = ((String) this.view.getAccountSelection().getSelectedItem());
        Logging.LOGGER.fine("Changing primary account selected: " + description);
        this.profile.setPrimaryAccount(description);
        this.view.setProfile(profile);
    }

    public AccountView getView() {
        return view;
    }
}
