package me.teridax.jcash.gui.deposit;

import me.teridax.jcash.Logging;
import me.teridax.jcash.decode.StringDecoder;

import javax.swing.*;
import java.awt.*;
import java.text.NumberFormat;
import java.text.ParseException;

import static me.teridax.jcash.lang.Translator.translate;

public class DepositView {

    private JDialog dialog;
    private JButton cancel;
    private JButton deposit;
    private JFormattedTextField value;

    public DepositView() {
        createComponents();
        layoutComponents();
    }

    public void showDialog() {
        dialog.setModalityType(Dialog.ModalityType.APPLICATION_MODAL);
        dialog.setTitle(translate("Deposit money"));
        dialog.pack();
        dialog.setResizable(false);
        dialog.setLocationRelativeTo(null);
        dialog.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
        dialog.setVisible(true);
    }

    private void layoutComponents() {
        dialog.getContentPane().setLayout(new GridBagLayout());

        var c = new GridBagConstraints();

        c.gridx = 0;
        c.gridy = 0;
        c.weightx = 1;
        c.weighty = 1;
        c.gridwidth = 3;
        c.fill = GridBagConstraints.HORIZONTAL;
        c.anchor = GridBagConstraints.CENTER;
        c.insets = new Insets(4, 4, 4, 4);
        dialog.getContentPane().add(new JLabel(translate("Deposit money")), c);

        c.gridx = 0;
        c.gridy = 1;
        c.gridwidth = 1;
        c.fill = GridBagConstraints.NONE;
        c.anchor = GridBagConstraints.LAST_LINE_END;
        c.weightx = 0;
        dialog.getContentPane().add(new JLabel(translate("Value"), SwingConstants.RIGHT), c);

        c.gridx = 1;
        c.gridy = 1;
        c.fill = GridBagConstraints.HORIZONTAL;
        c.anchor = GridBagConstraints.LAST_LINE_END;
        c.weightx = 0.5;
        dialog.getContentPane().add(value, c);

        c.gridx = 2;
        c.gridy = 1;
        c.fill = GridBagConstraints.NONE;
        c.anchor = GridBagConstraints.LINE_START;
        c.weightx = 0;
        dialog.getContentPane().add(new JLabel("€"), c);

        var buttonPanel = new JPanel(new FlowLayout(FlowLayout.TRAILING));
        buttonPanel.add(cancel);
        buttonPanel.add(deposit);

        c.gridx = 0;
        c.gridy = 2;
        c.gridwidth = 3;
        c.fill = GridBagConstraints.HORIZONTAL;
        c.anchor = GridBagConstraints.LAST_LINE_END;
        c.insets = new Insets(10, 10, 10, 10);
        dialog.getContentPane().add(buttonPanel, c);
    }

    private void createComponents() {
        this.dialog = new JDialog();

        this.cancel = new JButton(translate("Cancel"));
        this.deposit = new JButton(translate("Deposit"));
        this.value = new JFormattedTextField(StringDecoder.getNumberFormat());

        this.dialog.setContentPane(new JPanel(new GridBagLayout()));
    }

    public double getAmount() {
        if (value.getText().isBlank())
            return 0;

        try {
            return NumberFormat.getNumberInstance().parse(value.getText()).doubleValue();
        } catch (ParseException e) {
            Logging.LOGGER.severe("Amount text field contains invalid value: " + value);
            throw new RuntimeException(e);
        }
    }

    public JButton getCancel() {
        return cancel;
    }

    public JButton getDeposit() {
        return deposit;
    }

    public void dispose() {
        this.dialog.dispose();
    }
}
