package me.teridax.jcash.gui.transfer;

import me.teridax.jcash.Logging;
import me.teridax.jcash.Main;
import me.teridax.jcash.banking.accounts.Account;
import me.teridax.jcash.banking.management.BankingManagementSystem;

import static javax.swing.JOptionPane.ERROR_MESSAGE;
import static javax.swing.JOptionPane.showMessageDialog;
import static me.teridax.jcash.lang.Translator.translate;

/**
 * Dialog class for transferring some value from one account to another
 */
public class TransferDialog {

    private final Account account;
    private final Runnable onDeposit;
    private final TransferData transferData;
    private final TransferView transferView;

    public TransferDialog(Account account, BankingManagementSystem bms, Runnable onDeposit) {
        this.account = account;
        this.onDeposit = onDeposit;

        this.transferView = new TransferView();
        this.transferData = new TransferData(bms);
        this.transferView.getTransfer().addActionListener(e -> transfer());
        this.transferView.getCancel().addActionListener(e -> transferView.dispose());
        this.transferView.showDialog();
    }

    private void transfer() {
        try {
            var amount = transferView.getAmount();

            this.account.takeoff(amount);
            this.transferData.transferValue(amount, transferView.getBlz(), transferView.getIban());
            this.onDeposit.run();
            this.transferView.dispose();
        } catch (IllegalArgumentException ex) {
            Logging.LOGGER.severe("Could not transfer: " + ex.getMessage());
            showMessageDialog(Main.getInstance().getWindow(), translate("Invalid account"), translate("Could not transfer"), ERROR_MESSAGE);
        }
    }
}
